Method: Qa::Authorities::LinkedData::TermConfig#term_language

Defined in:
lib/qa/authorities/linked_data/config/term_config.rb

#term_languageSymbol Also known as: language

Return the preferred language for literal value selection for term fetch. Only applies if the authority provides language encoded literals. This is the default used for this authority if the user does not pass in a language. Only applies if the authority provides language encoded literals.

Returns:

  • (Symbol)

    the configured language for term fetch (default - :en)



52
53
54
55
56
57
58
# File 'lib/qa/authorities/linked_data/config/term_config.rb', line 52

def term_language
  return @term_language unless @term_language.nil?
  lang = Config.config_value(term_config, :language)
  return nil if lang.nil?
  lang = [lang] if lang.is_a? String
  @term_language = lang.collect(&:to_sym)
end